@@ -8,7 +8,7 @@
     
       Sources digging class (xgettext)
     
-      (c) Vaclav Slavik, 2000
+      (c) Vaclav Slavik, 2000,2004
 
 */
 
@@ -28,22 +28,24 @@
 #include "gexecute.h"
 
 Catalog *SourceDigger::Dig(const wxArrayString& paths, 
-                           const wxArrayString& keywords)
+                           const wxArrayString& keywords,
+                           const wxString& charset)
 {
     ParsersDB pdb;
     pdb.Read(wxConfig::Get());
 
-    m_ProgressInfo->UpdateMessage(_("Scanning files..."));
+    m_progressInfo->UpdateMessage(_("Scanning files..."));
 
     wxArrayString *all_files = FindFiles(paths, pdb);
     if (all_files == NULL) return NULL;
 
     Catalog *c = new Catalog;
+    c->CreateNewHeader();
         
     for (size_t i = 0; i < pdb.GetCount(); i++)
     {
-        m_ProgressInfo->UpdateMessage(_("Parsing ")+pdb[i].Name+_(" files..."));
-        if (!DigFiles(c, all_files[i], pdb[i], keywords))
+        m_progressInfo->UpdateMessage(_("Parsing ")+pdb[i].Name+_(" files..."));
+        if (!DigFiles(c, all_files[i], pdb[i], keywords, charset))
         { 
             delete[] all_files;
             delete c;
@@ -57,14 +59,16 @@ Catalog *SourceDigger::Dig(const wxArrayString& paths,
 
 
 
+// cmdline's length is limited by OS/shell, this is maximal number
+// of files we'll pass to the parser at one run:
 #define BATCH_SIZE  16
-  // cmdline's length is limited by OS/shell
 
 bool SourceDigger::DigFiles(Catalog *cat, const wxArrayString& files, 
-                            Parser &parser, const wxArrayString& keywords)
+                            Parser &parser, const wxArrayString& keywords,
+                            const wxString& charset)
 {
     wxArrayString batchfiles;
-    wxString tempfile = wxGetTempFileName("poedit");
+    wxString tempfile = wxGetTempFileName(_T("poedit"));
     Catalog *ctmp;
     size_t i, last = 0;
 
@@ -75,10 +79,13 @@ bool SourceDigger::DigFiles(Catalog *cat, const wxArrayString& files,
             batchfiles.Add(files[i]);
         last = i;
         
-        if (!ExecuteGettext(parser.GetCommand(batchfiles, keywords, tempfile)))
-	    return false;
-        m_ProgressInfo->UpdateGauge(batchfiles.GetCount());
-        if (m_ProgressInfo->Cancelled()) return false;
+        if (!ExecuteGettext(
+                    parser.GetCommand(batchfiles, keywords, tempfile, charset)))
+        {
+            return false;
+        }
+        m_progressInfo->UpdateGauge(batchfiles.GetCount());
+        if (m_progressInfo->Cancelled()) return false;
         
         ctmp = new Catalog(tempfile);
         cat->Append(*ctmp);
@@ -101,10 +108,10 @@ wxArrayString *SourceDigger::FindFiles(const wxArrayString& paths,
     
     for (i = 0; i < paths.GetCount(); i++)
         if (!FindInDir(paths[i], files))
-	{
-	    delete[] p_files;
-	    return NULL;
-	}
+    {
+        delete[] p_files;
+        return NULL;
+    }
 
     size_t filescnt = 0;
     for (i = 0; i < pdb.GetCount(); i++)
@@ -112,7 +119,14 @@ wxArrayString *SourceDigger::FindFiles(const wxArrayString& paths,
         p_files[i] = pdb[i].SelectParsable(files);
         filescnt += p_files[i].GetCount();
     }
-    m_ProgressInfo->SetGaugeMax(filescnt);
+    m_progressInfo->SetGaugeMax(filescnt);
+    
+    if (filescnt == 0)
+    {
+        for (i = 0; i < paths.GetCount(); i++)
+            wxLogWarning(_("No files found in: ") + paths[i]);
+        wxLogError(_("poEdit did not find any files in scanned directories."));
+    }
 
     return p_files;
 }
@@ -122,22 +136,23 @@ wxArrayString *SourceDigger::FindFiles(const wxArrayString& paths,
 bool SourceDigger::FindInDir(const wxString& dirname, wxArrayString& files)
 {
     wxDir dir(dirname);
-    if (!dir.IsOpened()) return false;
+    if (!dir.IsOpened()) 
+        return false;
     bool cont;
     wxString filename;
     
     cont = dir.GetFirst(&filename, wxEmptyString, wxDIR_FILES);
     while (cont)
     {
-        files.Add(dirname + "/" + filename);
+        files.Add(dirname + _T("/") + filename);
         cont = dir.GetNext(&filename);
     }    
 
     cont = dir.GetFirst(&filename, wxEmptyString, wxDIR_DIRS);
     while (cont)
     {
-        if (!FindInDir(dirname + "/" + filename, files))
-	    return false;
+        if (!FindInDir(dirname + _T("/") + filename, files))
+            return false;
         cont = dir.GetNext(&filename);
     }
     return true;
