@@ -13,7 +13,7 @@
 */
 
 
-#ifdef __GNUG__
+#if defined(__GNUG__) && !defined(__APPLE__)
 #pragma interface
 #endif
 
@@ -23,7 +23,9 @@
 class wxString;
 
 
-// executes command, logs stderr output and returns success
+/** Executes command. Logs stderr output with wxLogXXXX classes.
+    \return true if program exited with exit code 0, false otherwise.
+ */
 extern bool ExecuteGettext(const wxString& cmdline);
 
 #endif // _GEXECUTE_H_
