@@ -17,11 +17,13 @@
 #pragma implementation
 #endif
 
+#include <wx/wxprec.h>
+
 #include "progressinfo.h"
 
 #include <wx/dialog.h>
 #include <wx/log.h>
-#include <wx/xml/xmlres.h>
+#include <wx/xrc/xmlres.h>
 #include <wx/gauge.h>
 #include <wx/stattext.h>
 #include <wx/dialog.h>
@@ -31,17 +33,17 @@
 class ProgressDlg : public wxDialog
 {
     public:
-        ProgressDlg(bool *cancel) : wxDialog(), m_CancelFlag(cancel) {}
+        ProgressDlg(bool *cancel) : wxDialog(), m_cancelFlag(cancel) {}
         
     private:
-        bool *m_CancelFlag;
+        bool *m_cancelFlag;
     
         DECLARE_EVENT_TABLE()
 
         void OnCancel(wxCommandEvent& event)
         {
             ((wxButton*)FindWindow(wxID_CANCEL))->Enable(false);
-            *m_CancelFlag = true;
+            *m_cancelFlag = true;
         }
 };
 
@@ -49,58 +51,51 @@ BEGIN_EVENT_TABLE(ProgressDlg, wxDialog)
    EVT_BUTTON(wxID_CANCEL, ProgressDlg::OnCancel)
 END_EVENT_TABLE()
 
-
 ProgressInfo::ProgressInfo()
 {
-    m_Cancelled = false;
-    m_Dlg = new ProgressDlg(&m_Cancelled);
-    wxTheXmlResource->LoadDialog(m_Dlg, NULL, "parser_progress");
-    wxPoint pos(wxConfig::Get()->Read("progress_pos_x", -1),
-               wxConfig::Get()->Read("progress_pos_y", -1));
-    if (pos.x != -1 && pos.y != -1) m_Dlg->Move(pos);
-    m_Dlg->Show(true);
-    m_Disabler = new wxWindowDisabler(m_Dlg);
+    m_cancelled = false;
+    m_dlg = new ProgressDlg(&m_cancelled);
+    wxXmlResource::Get()->LoadDialog(m_dlg, NULL, _T("parser_progress"));
+    wxPoint pos(wxConfig::Get()->Read(_T("progress_pos_x"), -1),
+               wxConfig::Get()->Read(_T("progress_pos_y"), -1));
+    if (pos.x != -1 && pos.y != -1) m_dlg->Move(pos);
+    m_dlg->Show(true);
+    m_disabler = new wxWindowDisabler(m_dlg);
 }
 
-
-
 ProgressInfo::~ProgressInfo()
 {
-    delete m_Disabler;
-    wxConfig::Get()->Write("progress_pos_x", (long)m_Dlg->GetPosition().x);
-    wxConfig::Get()->Write("progress_pos_y", (long)m_Dlg->GetPosition().y);
-    m_Dlg->Destroy();
+    delete m_disabler;
+    wxConfig::Get()->Write(_T("progress_pos_x"), (long)m_dlg->GetPosition().x);
+    wxConfig::Get()->Write(_T("progress_pos_y"), (long)m_dlg->GetPosition().y);
+    m_dlg->Destroy();
 }
 
-
-
 void ProgressInfo::SetTitle(const wxString& text)
 {
-    m_Dlg->SetTitle(text);
+    m_dlg->SetTitle(text);
     wxYield();
 }
-
-
-            
+           
 void ProgressInfo::SetGaugeMax(int limit)
 {
-    XMLCTRL(*m_Dlg, "progress", wxGauge)->SetRange(limit);
+    XRCCTRL(*m_dlg, "progress", wxGauge)->SetRange(limit);
 }
 
-
-
 void ProgressInfo::UpdateGauge(int increment)
 {
-    wxGauge *g = XMLCTRL(*m_Dlg, "progress", wxGauge);
+    wxGauge *g = XRCCTRL(*m_dlg, "progress", wxGauge);
     g->SetValue(g->GetValue() + increment);
 }
 
-
+void ProgressInfo::ResetGauge(int value)
+{
+    XRCCTRL(*m_dlg, "progress", wxGauge)->SetValue(value);
+}
 
 void ProgressInfo::UpdateMessage(const wxString& text)
 {
-    XMLCTRL(*m_Dlg, "info", wxStaticText)->SetLabel(text);
-    m_Dlg->Refresh();
+    XRCCTRL(*m_dlg, "info", wxStaticText)->SetLabel(text);
+    m_dlg->Refresh();
     wxYield();
 }
-            
